@@ -19,7 +19,7 @@ require 'spec_helper'
 
 describe 'ceph::osds' do
 
-  shared_examples_for 'ceph osds' do
+  shared_examples 'ceph osds' do
     let :params do
       {
         :args => {
@@ -36,54 +36,24 @@ describe 'ceph::osds' do
     end
 
     it {
-      is_expected.to contain_ceph__osd('/dev/sdb').with(
+      should contain_ceph__osd('/dev/sdb').with(
         :ensure  => 'present',
         :journal => '/srv/journal',
-        :cluster => 'CLUSTER'
-    )
-      is_expected.to contain_ceph__osd('/srv/data').with(
+        :cluster => 'CLUSTER')
+      should contain_ceph__osd('/srv/data').with(
         :ensure  => 'present',
         :cluster => 'CLUSTER')
     }
   end
 
-  describe 'Ubuntu' do
-    let :facts do
-      {
-        :osfamily => 'Debian',
-        :operatingsystem => 'Ubuntu',
-      }
-    end
+  on_supported_os.each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
 
-    it_configures 'ceph osds'
+      it_behaves_like 'ceph osds'
+    end
   end
 
-  describe 'Debian' do
-    let :facts do
-      {
-        :osfamily => 'Debian',
-        :operatingsystem => 'Debian',
-      }
-    end
-
-    it_configures 'ceph osds'
-  end
-
-  describe 'RedHat' do
-    let :facts do
-      {
-        :osfamily => 'RedHat',
-        :operatingsystem => 'RedHat',
-      }
-    end
-
-    it_configures 'ceph osds'
-  end
 end
-
-# Local Variables:
-# compile-command: "cd ../..;
-#    bundle install --path=vendor;
-#    bundle exec rake spec
-# "
-# End:
